==> qmmp-plugin-pack_1.3.1.orig.tar.xz: src/Input/ffap/translations/ffap_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="43"/>
        <source>FFap Plugin</source>
        <translation>FFap　插件</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="45"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>猴子的音频文件</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="157"/>
        <source>About FFap Audio Plugin</source>
        <translation>关于FFap音频插件</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="158"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Qmmp FFap　音频插件</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="159"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>该插件提供猴子音频(APE)支持</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="160"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="161"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>基于deadbeef、FFmpeg及rockbox所含代码</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="67"/>
        <source>Samples</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="68"/>
        <source>Version</source>
        <translation>版本</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack_1.6.1.orig.tar.xz: src/Input/ffap/translations/ffap_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="43"/>
        <source>FFap Plugin</source>
        <translation>FFap&#x3000;插件</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="45"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>猴子的音频文件</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="150"/>
        <source>About FFap Audio Plugin</source>
        <translation>关于FFap音频插件</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="151"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Qmmp FFap&#x3000;音频插件</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="152"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>该插件提供猴子音频(APE)支持</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="153"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="154"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>基于deadbeef、FFmpeg及rockbox所含代码</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="65"/>
        <source>Samples</source>
        <translation>取样率</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="66"/>
        <source>Version</source>
        <translation>版本</translation>
    </message>
</context>
</TS>
